@@ -8,6 +8,7 @@ class S3List:
 
     def __init__(self, bucket, s3_client=None):
         """
+        From newtools 2.1.0 onwards, the list_folders method returns a set rather than a list.
         :param bucket: The s3 bucket to look for data in
         :param s3_client: optional pass in of a pre created boto3 s3 client
         """
@@ -17,9 +18,13 @@ class S3List:
     def list_folders(self, prefix=''):
         """
         :param prefix: prefix the data is stored under if empty string will scan at highest level of bucket
-        :return: returns a list of the folders at that level
+        :return: returns a set of the folders at that level (changed from list in 2.1.0 onwards)
         """
-        result_list = []
+        result_list = set()
+
+        # force prefix end with "/"
+        if prefix != '' and not prefix.endswith("/"):
+            prefix = prefix + "/"
 
         paginator = self.s3_client.get_paginator("list_objects_v2")
         pages = paginator.paginate(Bucket=self.bucket,
@@ -28,8 +33,9 @@ class S3List:
 
         for page in pages:
             if page.get('CommonPrefixes'):
-                common_prefixes = page.get('CommonPrefixes')
-                result_list.extend(common_prefixes)
+                for i in page['CommonPrefixes']:
+                    result_list.add(i['Prefix'])
+
 
         return result_list
 
@@ -59,7 +65,7 @@ class AthenaPartition:
                         of the bucket
         :return: A list of all the full paths of the partitions
         """
-        partition_depth = partition_depth or 100
+        partition_depth = partition_depth or 10
 
         if s3_path is None:
 
@@ -74,20 +80,20 @@ class AthenaPartition:
         partitions_tracked = 0
 
         while partitions_tracked < partition_depth:
-            temp_part_list = []
+            temp_part_list = set()
             for partition in partitions_list:
-                partitions_path_temp = list_files.list_folders(partition.get('Prefix'))
+                partitions_path_temp = list_files.list_folders(partition)
                 """
                 For each partition in the partition_list we check if there is any more depth, once we reach filename
-                `list_files.list_folders(partition.get('Prefix'))` will return [] we check for this and break from
+                `list_files.list_folders(partition)` will return an empty set we check for this and break from
                 checking the rest of the partitions, as all partitions have the same depth.
                 """
                 if not partitions_path_temp:
                     break
                 else:
-                    temp_part_list.extend(partitions_path_temp)
+                    temp_part_list.update(partitions_path_temp)
 
-            # If temp_part_list is still [] no further partitions have been found so we break out of the while loop.
+            # If temp_part_list is still empty, no further partitions have been found so we break out of the while loop.
 
             if temp_part_list:
                 partitions_list = temp_part_list
@@ -109,6 +115,7 @@ class AthenaPartition:
                 access the queries produced by it if in different account to default
                 :return: A list of queries that can be run to add all partitions
                 """
+
         s3_path = table if s3_path is None else s3_path
 
         if athena_client is not None:
@@ -124,13 +131,13 @@ class AthenaPartition:
                            compression=None, client=athena_s3_client)
             with fm as f:
                 athena_list = f.read().decode().splitlines()
-            athena_list = [{'Prefix': '{table}/{partition}/'.format(table=table, partition=partition)} for partition in
-                           athena_list]
-            partitions_list = [i for i in partitions_list if i not in athena_list]
+            athena_list = {'{table}/{partition}/'.format(table=s3_path, partition=partition) for partition in
+                           athena_list}
+            partitions_list = partitions_list - athena_list
 
         partition_string_list = []
         for i in partitions_list:
-            partition_string = i.get('Prefix')
+            partition_string = i
             location = S3Location(bucket=self.s3_bucket, key=partition_string, ignore_double_slash=True)
             partition_string = partition_string.replace(s3_path, "")
             partition_string = partition_string.rstrip('/')
