@@ -54,18 +54,18 @@ class TestLoadPartitions(unittest.TestCase):
         cls.athena_client.wait_for_completion()
 
     def test_list_folder(self):
-        folders = [{'Prefix': 'load_partition_test_data/year=2019/'}, {'Prefix': 'load_partition_test_data/year=2020/'}]
+        folders = {'load_partition_test_data/year=2019/', 'load_partition_test_data/year=2020/'}
         test_folders = self.s3_list_folders.list_folders(self.prefix)
-        self.assertListEqual(folders, test_folders)
+        self.assertCountEqual(folders, test_folders)
 
     def test_list_partitions(self):
-        partitions_list = [{'Prefix': 'load_partition_test_data/year=2019/month=02/some_more_directory/'},
-                           {'Prefix': 'load_partition_test_data/year=2019/month=0:2/some_more_directory/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=01/some_more_directory/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=01/some_more_directory_1/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=02/some_more_directory/'}]
+        partitions_list = {'load_partition_test_data/year=2019/month=02/some_more_directory/',
+                           'load_partition_test_data/year=2019/month=0:2/some_more_directory/',
+                           'load_partition_test_data/year=2020/month=01/some_more_directory/',
+                           'load_partition_test_data/year=2020/month=01/some_more_directory_1/',
+                           'load_partition_test_data/year=2020/month=02/some_more_directory/'}
         test_partitions_list = self.load_partitions.list_partitions('load_partition_test_data')
-        self.assertListEqual(partitions_list, test_partitions_list)
+        self.assertCountEqual(partitions_list, test_partitions_list)
 
     def test_list_partitions_error(self):
         with self.assertRaises(ValueError):
@@ -75,26 +75,26 @@ class TestLoadPartitions(unittest.TestCase):
         sql_query_list = [
             "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1/' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory/'"]
         test_sql_query_list = self.load_partitions.get_sql('load_partition_test_data')
-        self.assertListEqual(sql_query_list, test_sql_query_list)
+        self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
+                              [x.strip() for x in test_sql_query_list[0].split('PARTITION')])
 
     def test_generate_sql(self):
-        partitions_list = [{'Prefix': 'load_partition_test_data/year=2019/month=02/some_more_directory/'},
-                           {'Prefix': 'load_partition_test_data/year=2019/month=0:2/some_more_directory/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=01/some_more_directory/'},
-
-                           ]
+        partitions_list = {'load_partition_test_data/year=2019/month=02/some_more_directory/',
+                           'load_partition_test_data/year=2019/month=0:2/some_more_directory/',
+                           'load_partition_test_data/year=2020/month=01/some_more_directory/'}
 
         sql_query_list = [
             "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/'"]
 
         sql_query_list_test = self.load_partitions.generate_sql('load_partition_test_data', partitions_list)
-        self.assertListEqual(sql_query_list, sql_query_list_test)
+        self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
+                              [x.strip() for x in sql_query_list_test[0].split('PARTITION')])
 
     def test_generate_sql_with_client(self):
-        partitions_list = [{'Prefix': 'load_partition_test_data/year=2019/month=02/'},
-                           {'Prefix': 'load_partition_test_data/year=2019/month=0:2/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=01/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=02/'}]
+        partitions_list = {'load_partition_test_data/year=2019/month=02/',
+                           'load_partition_test_data/year=2019/month=0:2/',
+                           'load_partition_test_data/year=2020/month=01/',
+                           'load_partition_test_data/year=2020/month=02/'}
 
         sql_query_list = [
             "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/'"]
@@ -102,12 +102,12 @@ class TestLoadPartitions(unittest.TestCase):
         sql_query_list_test = self.load_partitions.generate_sql('load_partition_test_data', partitions_list,
                                                                 athena_client=self.athena_client,
                                                                 output_location=self.output_location)
-        self.assertListEqual(sql_query_list, sql_query_list_test)
+        self.assertCountEqual(sql_query_list, sql_query_list_test)
 
     def test_generate_sql_with_client_error(self):
-        partitions_list = [{'Prefix': 'load_partition_test_data/year=2019/month=02/'},
-                           {'Prefix': 'load_partition_test_data/year=2019/month=0:2/'},
-                           {'Prefix': 'load_partition_test_data/year=2020/month=01/'}]
+        partitions_list = {'load_partition_test_data/year=2019/month=02/',
+                           'load_partition_test_data/year=2019/month=0:2/',
+                           'load_partition_test_data/year=2020/month=01/'}
 
         with self.assertRaises(ValueError):
             self.load_partitions.generate_sql('load_partition_test_data', partitions_list,
